summaryrefslogtreecommitdiff
path: root/src/modules/m_swhois.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/modules/m_swhois.cpp')
-rw-r--r--src/modules/m_swhois.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/modules/m_swhois.cpp b/src/modules/m_swhois.cpp
index 7a2963281..dc53f2f0c 100644
--- a/src/modules/m_swhois.cpp
+++ b/src/modules/m_swhois.cpp
@@ -25,7 +25,7 @@
#include "inspircd.h"
/* $ModDesc: Provides the SWHOIS command which allows setting of arbitary WHOIS lines */
/** Handle /SWHOIS
*/
@@ -133,7 +133,7 @@ class ModuleSWhois : public Module
Version GetVersion()
{
- return Version("Provides the SWHOIS command which allows setting of arbitary WHOIS lines", VF_OPTCOMMON | VF_VENDOR);
+ return Version("Provides the SWHOIS command which allows setting of arbitrary WHOIS lines", VF_OPTCOMMON | VF_VENDOR);
}
};
@@ -25,7 +25,7 @@
#include "inspircd.h"
-/* $ModDesc: Provides the SWHOIS command which allows setting of arbitary WHOIS lines */
+/* $ModDesc: Provides the SWHOIS command which allows setting of arbitrary WHOIS lines */
/** Handle /SWHOIS
*/